MetricTemplate

Struct MetricTemplate 

pub struct MetricTemplate {
    pub selectors: Vec<String>,
    pub metric_id: MetricId,
    pub metric_type: MetricType,
    pub event_codes: Vec<EventCode>,
    pub upload_once: bool,
}
Configuration for a single FIRE metric template to map from an Inspect property to a cobalt metric. Unlike MetricConfig, selectors aren’t parsed.

Fields

selectors: Vec<String>

Selector identifying the metric to sample via the diagnostics platform.

metric_id: MetricId

Cobalt metric id to map the selector to.

metric_type: MetricType

Data type to transform the metric to.

event_codes: Vec<EventCode>

Event codes defining the dimensions of the cobalt metric. Notes:

  • Order matters, and must match the order of the defined dimensions in the cobalt metric file.
  • The FIRE component-ID will be inserted as the first element of event_codes.
  • The event_codes field may be omitted from the config file if component-ID is the only event code.
upload_once: bool

Optional boolean specifying whether to upload the specified metric only once, the first time it becomes available to the sampler. Defaults to false.