pub struct DataSetConfig {
pub poll_rate_sec: i64,
pub metrics: Vec<MetricConfig>,
}Expand description
Grouping unit for metrics within a single project that share a polling frequency.
Fields
poll_rate_sec: i64The frequency with which metrics are sampled, in seconds.
metrics: Vec<MetricConfig>The collection of mappings from Inspect to Cobalt.