MetricConfig

Struct MetricConfig 

pub struct MetricConfig {
    pub selectors: Vec<Selector>,
    pub metric_id: MetricId,
    pub metric_type: MetricType,
    pub event_codes: Vec<EventCode>,
    pub upload_once: bool,
}
Configuration for a single metric to map from an Inspect property to a Cobalt metric.

Fields

selectors: Vec<Selector>

Selector identifying the metric to sample via the diagnostics platform.

metric_id: MetricId

Cobalt metric id to map the selector to.

metric_type: MetricType

Data type to transform the metric to.

event_codes: Vec<EventCode>

Event codes defining the dimensions of the Cobalt metric. Note: Order matters, and must match the order of the defined dimensions in the Cobalt metric file. Missing field means the same as empty list.

upload_once: bool

Optional boolean specifying whether to upload the specified metric only once, the first time it becomes available to the sampler. Defaults to false.